AppService

Struct AppService 

pub struct AppService {
Show 13 fields pub id: String, pub url: Option<String>, pub as_token: String, pub hs_token: String, pub sender_localpart: Option<String>, pub users: Vec<AppServiceNamespace>, pub aliases: Vec<AppServiceNamespace>, pub rooms: Vec<AppServiceNamespace>, pub rate_limited: bool, pub protocols: Vec<String>, pub receive_ephemeral: bool, pub device_management: bool, pub msc3202_transaction_extensions: bool,
}
Defines one inline Matrix application service registration.

Tokens, namespaces, and protocol flags are converted to the Matrix registration model. The enclosing config map supplies the registration ID when id is empty.

Fields

id: String

Identifies the application service registration.

An empty value is replaced with the enclosing config map key. An explicit value must match that key.

url: Option<String>

The URL for the application service.

Optionally set to null if no traffic is required.

as_token: String

A unique token for application services to use to authenticate requests to Homeservers.

default: display: sensitive

hs_token: String

A unique token for Homeservers to use to authenticate requests to application services.

default: display: sensitive

sender_localpart: Option<String>

The localpart of the user associated with the application service.

users: Vec<AppServiceNamespace>

Events which are sent from certain users.

aliases: Vec<AppServiceNamespace>

Events which are sent in rooms with certain room aliases.

rooms: Vec<AppServiceNamespace>

Events which are sent in rooms with certain room IDs.

rate_limited: bool

Whether requests from masqueraded users are rate-limited.

The sender is excluded.

protocols: Vec<String>

The external protocols which the application service provides (e.g. IRC).

default: []

receive_ephemeral: bool

Whether the application service wants to receive ephemeral data.

default: false

device_management: bool

Whether the application service wants to do device management, as part of MSC4190.

default: false

msc3202_transaction_extensions: bool

Whether the application service wants MSC3202 transaction extensions (device lists, one-time-key counts, and unused fallback key types).

The registration-file key is org.matrix.msc3202; this inline-config key is msc3202_transaction_extensions.

default: false