JwtConfig

Struct JwtConfig 

pub struct JwtConfig {
    pub enable: bool,
    pub key: String,
    pub format: String,
    pub register_user: bool,
    pub algorithm: String,
    pub audience: Vec<String>,
    pub issuer: Vec<String>,
    pub require_exp: bool,
    pub require_nbf: bool,
    pub validate_exp: bool,
    pub validate_nbf: bool,
    pub validate_signature: bool,
}

Fields

enable: bool

Enable JWT logins

reloadable: yes default: false

key: String

Validation key, also called ‘secret’ in Synapse config. The type of key can be configured in ‘format’, but defaults to the common HMAC which is a plaintext shared-secret, so you should keep this value private.

display: sensitive reloadable: yes default:

format: String

Format of the ‘key’. Only HMAC, ECDSA, and B64HMAC are supported Binary keys cannot be pasted into this config, so B64HMAC is an alternative to HMAC for properly random secret strings.

  • HMAC is a plaintext shared-secret private-key.
  • B64HMAC is a base64-encoded version of HMAC.
  • ECDSA is a PEM-encoded public-key.
  • EDDSA is a PEM-encoded Ed25519 public-key.

reloadable: yes default: “HMAC”

register_user: bool

Automatically create new user from a valid claim, otherwise access is denied for an unknown even with an authentic token.

reloadable: yes default: true

algorithm: String

JWT algorithm

reloadable: yes default: “HS256”

audience: Vec<String>

Optional audience claim list. The token must claim one or more values from this list when set.

reloadable: yes default: []

issuer: Vec<String>

Optional issuer claim list. The token must claim one or more values from this list when set.

reloadable: yes default: []

require_exp: bool

Require expiration claim in the token. This defaults to false for synapse migration compatibility.

reloadable: yes default: false

require_nbf: bool

Require not-before claim in the token. This defaults to false for synapse migration compatibility.

reloadable: yes default: false

validate_exp: bool

Validate expiration time of the token when present. Whether or not it is required depends on require_exp, but when present this ensures the token is not used after a time.

reloadable: yes default: true

validate_nbf: bool

Validate not-before time of the token when present. Whether or not it is required depends on require_nbf, but when present this ensures the token is not used before a time.

reloadable: yes default: true

validate_signature: bool

Bypass validation for diagnostic/debug use only.

reloadable: yes default: true