pub struct LdapConfig {
pub enable: bool,
pub uri: Option<Url>,
pub base_dn: String,
pub bind_dn: Option<String>,
pub bind_password_file: Option<PathBuf>,
pub filter: String,
pub uid_attribute: String,
pub name_attribute: String,
pub admin_base_dn: String,
pub admin_filter: String,
}Fields
enable: boolWhether to enable LDAP login.
reloadable: yes example: “true”
uri: Option<Url>URI of the LDAP server.
reloadable: yes example: “ldap://ldap.example.com:389”
base_dn: StringRoot of the searches.
reloadable: yes example: “ou=users,dc=example,dc=org”
default:
bind_dn: Option<String>Bind DN if anonymous search is not enabled.
You can use the variable {username} that will be replaced by the
entered username. In such case, the password used to bind will be the
one provided for the login and not the one given by
bind_password_file. Beware: automatically granting admin rights will
not work if you use this direct bind instead of a LDAP search.
reloadable: yes example: “cn=ldap-reader,dc=example,dc=org” or “cn={username},ou=users,dc=example,dc=org”
default: “”
bind_password_file: Option<PathBuf>Path to a file on the system that contains the password for the
bind_dn.
The server must be able to access the file, and it must not be empty.
reloadable: yes default: “”
filter: StringSearch filter to limit user searches.
You can use the variable {username} that will be replaced by the
entered username for more complex filters.
reloadable: yes example: “(&(objectClass=person)(memberOf=matrix))”
default: “(objectClass=*)”
uid_attribute: StringAttribute to use to uniquely identify the user.
reloadable: yes example: “uid” or “cn”
default: “uid”
name_attribute: StringAttribute containing the distinguished name of the user.
reloadable: yes example: “givenName” or “sn”
default: “givenName”
admin_base_dn: StringRoot of the searches for admin users.
Defaults to base_dn if empty.
reloadable: yes example: “ou=admins,dc=example,dc=org”
default:
admin_filter: StringThe LDAP search filter to find administrative users for tuwunel.
If left blank, administrative state must be configured manually for each user.
You can use the variable {username} that will be replaced by the
entered username for more complex filters.
reloadable: yes example: “(objectClass=tuwunelAdmin)” or “(uid={username})”
default: