logging

Function logging 

pub const fn logging() -> bool
Returns true if debug logging is enabled. In this mode extra logging calls are made at all log levels, not just DEBUG and TRACE. These logs are demoted to DEBUG level when this function returns false; as a consequence they will be elided by release_max_log_level when featured.