Enum RoomVersion
pub enum RoomVersion {
Show 13 variants
V1,
V2,
V3,
V4,
V5,
V6,
V7,
V8,
V9,
V10,
V11,
V12,
MSC2870,
// some variants omitted
}Expand description
A Matrix room version ID.
A RoomVersionId can be or converted or deserialized from a string slice, and can be converted
or serialized back into a string as needed.
assert_eq!(RoomVersionId::try_from("1").unwrap().as_str(), "1");Any string consisting of at minimum 1, at maximum 32 unicode codepoints is a room version ID.
Custom room versions or ones that were introduced into the specification after this code was
written are represented by a hidden enum variant. You can still construct them the same, and
check for them using one of RoomVersionIds PartialEq implementations or through .as_str().
The PartialOrd and Ord implementations of this type sort the variants by comparing their
string representations, which have no special meaning. To check the compatibility between
room versions, one should use the RoomVersionRules instead.
Variants
V1
A version 1 room.
V2
A version 2 room.
V3
A version 3 room.
V4
A version 4 room.
V5
A version 5 room.
V6
A version 6 room.
V7
A version 7 room.
V8
A version 8 room.
V9
A version 9 room.
V10
A version 10 room.
V11
A version 11 room.
V12
A version 12 room.
MSC2870
org.matrix.msc2870 (MSC2870).
Implementations
impl RoomVersionId
impl RoomVersionId
pub fn rules(&self) -> Option<RoomVersionRules>
pub fn rules(&self) -> Option<RoomVersionRules>
Get the RoomVersionRules for this RoomVersionId, if it matches a supported room
version.
All known variants are guaranteed to return Some(_).