map_log

Function map_log 

pub fn map_log<E>(error: E) -> Error
where Error: From<E>,
Converts and logs an error while returning the converted value.

Display-formatted logging occurs after conversion to Error. The same converted error is returned for propagation by combinator chains.