default_debug_log

Function default_debug_log 

pub fn default_debug_log<T, E>(error: E) -> T
where T: Default, Error: From<E>,
Debug-logs an error and returns a default value.

The input is converted to Error before using the debug-aware logging path. The result is independent of the error and comes from Default::default.