fn extend_scope<S>(
payload: &mut SmallVec<[u8; 128]>,
event: &Event<'_>,
ctx: &Context<'_, S>,
)where
S: Subscriber + for<'a> LookupSpan<'a>,Expand description
Appends the fields of every span enclosing the event, innermost first.
fn extend_scope<S>(
payload: &mut SmallVec<[u8; 128]>,
event: &Event<'_>,
ctx: &Context<'_, S>,
)where
S: Subscriber + for<'a> LookupSpan<'a>,Appends the fields of every span enclosing the event, innermost first.