fn record_span<S>(attrs: &Attributes<'_>, id: &Id, ctx: &Context<'_, S>)where
S: Subscriber + for<'a> LookupSpan<'a>,Expand description
Encodes a span’s fields once, for every event it later encloses.
fn record_span<S>(attrs: &Attributes<'_>, id: &Id, ctx: &Context<'_, S>)where
S: Subscriber + for<'a> LookupSpan<'a>,Encodes a span’s fields once, for every event it later encloses.