fn record_values<S>(id: &Id, values: &Record<'_>, ctx: &Context<'_, S>)where
S: Subscriber + for<'a> LookupSpan<'a>,Expand description
Appends the fields of a span recorded after its creation.
fn record_values<S>(id: &Id, values: &Record<'_>, ctx: &Context<'_, S>)where
S: Subscriber + for<'a> LookupSpan<'a>,Appends the fields of a span recorded after its creation.