pub struct Fields<L> {
inner: L,
submit: bool,
}Expand description
Records the fields of each event and span for the entry the wrapped
console layer is about to write, leaving them queryable with
journalctl F_NAME=value.
Fields
inner: Lsubmit: boolImplementations