Metadata

Struct Metadata 

pub struct Metadata<'a> {
    name: &'static str,
    target: &'a str,
    level: Level,
    module_path: Option<&'a str>,
    file: Option<&'a str>,
    line: Option<u32>,
    fields: FieldSet,
    kind: Kind,
}
Metadata describing a span or event.

All spans and events have the following metadata:

  • A name, represented as a static string.
  • A target, a string that categorizes part of the system where the span or event occurred. The tracing macros default to using the module path where the span or event originated as the target, but it may be overridden.
  • A verbosity level. This determines how verbose a given span or event is, and allows enabling or disabling more verbose diagnostics situationally. See the documentation for the Level type for details.
  • The names of the fields defined by the span or event.
  • Whether the metadata corresponds to a span or event.

In addition, the following optional metadata describing the source code location where the span or event originated may be provided:

Metadata is used by Subscribers when filtering spans and events, and it may also be used as part of their data payload.

When created by the event! or span! macro, the metadata describing a particular event or span is constructed statically and exists as a single static instance. Thus, the overhead of creating the metadata is significantly lower than that of creating the actual span. Therefore, filtering is based on metadata, rather than on the constructed span.

Equality

In well-behaved applications, two Metadata with equal callsite identifiers will be equal in all other ways (i.e., have the same name, target, etc.). Consequently, in release builds, Metadata::eq only checks that its arguments have equal callsites. However, the equality of Metadata’s other fields is checked in debug builds.

Fields

name: &'static strtarget: &'a strlevel: Levelmodule_path: Option<&'a str>file: Option<&'a str>line: Option<u32>fields: FieldSetkind: Kind

Implementations



impl<'a> Metadata<'a>

pub const fn new( name: &'static str, target: &'a str, level: Level, file: Option<&'a str>, line: Option<u32>, module_path: Option<&'a str>, fields: FieldSet, kind: Kind, ) -> Metadata<'a>

Construct new metadata for a span or event, with a name, target, level, field names, and optional source code location.

pub fn fields(&self) -> &FieldSet

Returns the names of the fields on the described span or event.

pub fn level(&self) -> &Level

Returns the level of verbosity of the described span or event.

pub fn name(&self) -> &'static str

Returns the name of the span.

pub fn target(&self) -> &'a str

Returns a string describing the part of the system where the span or event that this metadata describes occurred.

Typically, this is the module path, but alternate targets may be set when spans or events are constructed.

pub fn module_path(&self) -> Option<&'a str>

Returns the path to the Rust module where the span occurred, or None if the module path is unknown.

pub fn file(&self) -> Option<&'a str>

Returns the name of the source code file where the span occurred, or None if the file is unknown

pub fn line(&self) -> Option<u32>

Returns the line number in the source code file where the span occurred, or None if the line number is unknown.

pub fn callsite(&self) -> Identifier

Returns an opaque Identifier that uniquely identifies the callsite this Metadata originated from.

pub fn is_event(&self) -> bool

Returns true if the callsite kind is Event.

pub fn is_span(&self) -> bool

Return true if the callsite kind is Span.