macro_rules! debug_error {
( $($x:tt)+ ) => { ... };
}Expand description
Emits an error event through debug-aware level control.
When extra debug logging is disabled, the event is demoted to DEBUG and
may be removed by compile-time filtering.
macro_rules! debug_error {
( $($x:tt)+ ) => { ... };
}Emits an error event through debug-aware level control.
When extra debug logging is disabled, the event is demoted to DEBUG and
may be removed by compile-time filtering.