err_lev

Macro err_lev 

macro_rules! err_lev {
    (debug_warn) => { ... };
    (debug_error) => { ... };
    (warn) => { ... };
    (error) => { ... };
}
Resolves an error macro level to a tracing level.

Debug-sensitive warning and error levels fall back to DEBUG outside debug logging mode. Fixed warning and error inputs retain their respective levels.