extract

Macro extract 

macro_rules! extract {
    ($e:expr_2021, $out:ident in $variant:pat) => { ... };
}
Extracts a pattern-bound value into an Option.

The expression is matched once against the supplied pattern. A match returns the named binding in Some, while every other value returns None.