macro_rules! is_not_empty {
() => { ... };
}Expand description
Creates a closure that reports whether its input is nonempty.
The generated closure delegates to is_empty and negates the result.
macro_rules! is_not_empty {
() => { ... };
}Creates a closure that reports whether its input is nonempty.
The generated closure delegates to is_empty and negates the result.