macro_rules! is_true {
() => { ... };
}Expand description
Creates a Boolean identity closure.
The generated closure applies logical negation twice, making it usable where a predicate function is required.
macro_rules! is_true {
() => { ... };
}Creates a Boolean identity closure.
The generated closure applies logical negation twice, making it usable where a predicate function is required.