macro_rules! is_zero {
() => { ... };
}Expand description
Creates a closure that reports whether its input matches zero.
The generated closure uses a literal pattern through is_matching!.
macro_rules! is_zero {
() => { ... };
}Creates a closure that reports whether its input matches zero.
The generated closure uses a literal pattern through is_matching!.