macro_rules! mod_ctor {
() => { ... };
}Expand description
Defines an empty module-constructor hook.
Builds without dynamic module support can keep the same mod_ctor!
invocation as enabled builds. Invoking it emits no constructor.
macro_rules! mod_ctor {
() => { ... };
}Defines an empty module-constructor hook.
Builds without dynamic module support can keep the same mod_ctor!
invocation as enabled builds. Invoking it emits no constructor.