macro_rules! mod_dtor {
() => { ... };
}Expand description
Defines an empty module-destructor hook.
Builds without dynamic module support can keep the same mod_dtor!
invocation as enabled builds. Invoking it emits no destructor.
macro_rules! mod_dtor {
() => { ... };
}Defines an empty module-destructor hook.
Builds without dynamic module support can keep the same mod_dtor!
invocation as enabled builds. Invoking it emits no destructor.