ref_at

Macro ref_at 

macro_rules! ref_at {
    ($idx:tt) => { ... };
}
Creates a closure that borrows an indexed tuple field.

The generated ref pattern borrows the tuple argument before returning a reference to the selected field.