macro_rules! unhandled {
($msg:literal) => { ... };
}Expand description
Marks an unsupported branch and panics with the supplied message.
The expansion delegates to crate::maybe_unhandled! and always retains a
runtime failure path.
macro_rules! unhandled {
($msg:literal) => { ... };
}Marks an unsupported branch and panics with the supplied message.
The expansion delegates to crate::maybe_unhandled! and always retains a
runtime failure path.