remove_relation_bundle_canonical

Function remove_relation_bundle_canonical 

fn remove_relation_bundle_canonical(
    pdu: &mut Pdu,
    relation_type: &str,
) -> Result
Canonicalize malformed or ambiguous relation objects while removing only the requested relation. This allocation is reserved for the error path of the borrowed surgical rewrite.