from_create_content

Function from_create_content 

pub fn from_create_content(content: &RoomCreateEventContent) -> &RoomVersionId
Borrows the room version from parsed room creation content.

Ruma applies the protocol default while deserializing content that omits the field. This accessor performs no additional validation.