from_create_event

Function from_create_event 

pub fn from_create_event<Pdu: Event>(
    create_event: &Pdu,
) -> Result<RoomVersionId>
Extracts the room version declared by a room creation event.

The event content is deserialized as m.room.create content. The returned identifier is owned independently of the event.