Struct RoomVersionRules
pub struct RoomVersionRules {
pub disposition: RoomVersionDisposition,
pub event_id_format: EventIdFormatVersion,
pub room_id_format: RoomIdFormatVersion,
pub events_reference_format: EventsReferenceFormatVersion,
pub state_res: StateResolutionVersion,
pub enforce_key_validity: bool,
pub authorization: AuthorizationRules,
pub redaction: RedactionRules,
pub signatures: SignaturesRules,
pub event_format: EventFormatRules,
}Expand description
The rules applied to a room version.
This type can be constructed from one of its constants (like RoomVersionRules::V1), or from
RoomVersionId::rules().
Fields
disposition: RoomVersionDispositionThe stability of the room version.
event_id_format: EventIdFormatVersionThe format of event IDs.
room_id_format: RoomIdFormatVersionThe format of room IDs.
events_reference_format: EventsReferenceFormatVersionThe format of arrays referencing events in PDUs.
state_res: StateResolutionVersionThe state resolution algorithm used.
enforce_key_validity: boolWhether to enforce the key validity period when verifying signatures (spec), introduced in room version 5.
The tweaks in the authorization rules.
redaction: RedactionRulesThe tweaks in the redaction algorithm.
signatures: SignaturesRulesThe tweaks for verifying signatures.
event_format: EventFormatRulesThe tweaks for verifying the event format.
Implementations
impl RoomVersionRules
impl RoomVersionRules
pub const V1: RoomVersionRules
pub const V1: RoomVersionRules
Rules for room version 1.
pub const V2: RoomVersionRules
pub const V2: RoomVersionRules
Rules for room version 2.
pub const V3: RoomVersionRules
pub const V3: RoomVersionRules
Rules for room version 3.
pub const V4: RoomVersionRules
pub const V4: RoomVersionRules
Rules for room version 4.
pub const V5: RoomVersionRules
pub const V5: RoomVersionRules
Rules for room version 5.
pub const V6: RoomVersionRules
pub const V6: RoomVersionRules
Rules for room version 6.
pub const V7: RoomVersionRules
pub const V7: RoomVersionRules
Rules for room version 7.
pub const V8: RoomVersionRules
pub const V8: RoomVersionRules
Rules for room version 8.
pub const V9: RoomVersionRules
pub const V9: RoomVersionRules
Rules for room version 9.
pub const V10: RoomVersionRules
pub const V10: RoomVersionRules
Rules for room version 10.
pub const V11: RoomVersionRules
pub const V11: RoomVersionRules
Rules for room version 11.
pub const V12: RoomVersionRules
pub const V12: RoomVersionRules
Rules for room version 12.
pub const MSC2870: RoomVersionRules
pub const MSC2870: RoomVersionRules
Rules for room version org.matrix.msc2870 (MSC2870).