pub fn deserialize_bytesize_u64<'de, D>(de: D) -> Result<u64, D::Error>where
D: Deserializer<'de>,Expand description
Accepts an integer byte count or a string with SI/IEC suffix (e.g. “32 MiB”)
and returns a u64.
pub fn deserialize_bytesize_u64<'de, D>(de: D) -> Result<u64, D::Error>where
D: Deserializer<'de>,Accepts an integer byte count or a string with SI/IEC suffix (e.g. “32 MiB”)
and returns a u64.