pub fn deserialize_bytesize_usize<'de, D>(de: D) -> Result<usize, D::Error>where
D: Deserializer<'de>,Expand description
Accepts an integer byte count or a string with SI/IEC suffix (e.g. “24 MiB”)
and returns a usize.
pub fn deserialize_bytesize_usize<'de, D>(de: D) -> Result<usize, D::Error>where
D: Deserializer<'de>,Accepts an integer byte count or a string with SI/IEC suffix (e.g. “24 MiB”)
and returns a usize.