slice_truncated

Function slice_truncated 

pub fn slice_truncated<T: Debug>(
    slice: &[T],
    max_len: usize,
) -> DebugValue<TruncatedSlice<'_, T>>
Creates a tracing debug value that truncates a slice.

The returned value can be recorded directly in a structured tracing field. At most max_len slice elements are formatted before the ellipsis marker.