or

Function or 

pub fn or<I, F>(args: I) -> impl Future<Output = bool> + Send
where I: Iterator<Item = F> + Send, F: Future<Output = bool> + Send + Unpin,
Computes the disjunction of an iterator of Boolean futures.

All inputs are polled concurrently and true short-circuits the operation. False is returned only after every input resolves to false.

Panics

Panics when the iterator contains no futures.