intersection

Function intersection 

pub fn intersection<Item, Iter, Iters>(
    input: Iters,
) -> impl Iterator<Item = Item> + Send
where Iters: Iterator<Item = Iter> + Clone + Send, Iter: Iterator<Item = Item> + Send, Item: Eq,
Intersection of sets

Outputs the set of elements common to all input sets. Inputs do not have to be sorted. If inputs are sorted a more optimized function is available in this suite and should be used.