set_width

Function set_width 

pub fn set_width(width: usize) -> (usize, usize)
Sets the live concurrency factor. The first return value is the previous width which was replaced. The second return value is the value which was set after any applied limits.