set_amplification

Function set_amplification 

pub fn set_amplification(width: usize) -> (usize, usize)
Sets the live concurrency amplification. The first return value is the previous width which was replaced. The second return value is the value which was set after any applied limits.