nth_core_available

Function nth_core_available 

pub fn nth_core_available(i: usize) -> Option<usize>
Gets the ID of the nth core available. This bijects our sequence of cores to actual ID’s which may have gaps for cores which are not available.