max_file_descriptors

Function max_file_descriptors 

pub fn max_file_descriptors() -> Result<(usize, usize)>
Returns the soft and hard file-descriptor limits.

The tuple is ordered as the current soft limit followed by the maximum hard limit. Values come from RLIMIT_NOFILE.

Panics

Panics when either platform limit cannot be represented as usize.