max_memory_locked

Function max_memory_locked 

pub fn max_memory_locked() -> Result<(usize, usize)>
Returns the soft and hard locked-memory limits.

The tuple is ordered as the current soft limit followed by the maximum hard limit. Values come from RLIMIT_MEMLOCK.

Panics

Panics when either platform limit cannot be represented as usize.