maximize_fd_limit

Function maximize_fd_limit 

pub fn maximize_fd_limit() -> Result
Raises the soft file descriptor limit to the current hard limit.

RocksDB and concurrent federation connections can exceed the common soft limit of 1,024 during startup. Systemd commonly provides a hard limit of 524,288.