pub fn format(ts: SystemTime, str: &str) -> StringExpand description
Formats a system time in UTC with a Chrono format string.
The pattern is passed to Chrono without modification. The rendered value is returned as an owned string.
pub fn format(ts: SystemTime, str: &str) -> StringFormats a system time in UTC with a Chrono format string.
The pattern is passed to Chrono without modification. The rendered value is returned as an owned string.