now_secs

Function now_secs 

pub fn now_secs() -> u64
Returns the current wall-clock time as whole seconds since the Unix epoch.

The subsecond remainder is discarded. The function panics if the current system clock is earlier than the epoch.