timepoint_ago

Function timepoint_ago 

pub fn timepoint_ago(duration: Duration) -> Result<SystemTime>
Subtracts a duration from the current wall-clock time using checked arithmetic.

The current time is sampled once for the calculation. An arithmetic error is returned when the result precedes the platform’s SystemTime range.