timepoint_from_now

Function timepoint_from_now 

pub fn timepoint_from_now(duration: Duration) -> Result<SystemTime>
Adds a duration to the current wall-clock time using checked arithmetic.

The current time is sampled once for the calculation. An arithmetic error is returned when the result exceeds the platform’s SystemTime range.