timepoint_has_passed

Function timepoint_has_passed 

pub fn timepoint_has_passed(timepoint: SystemTime) -> bool
Checks whether a system time is at or before the current wall-clock time.

Equality is considered passed. A time later than the sampled current time returns false.