whole_unit

Function whole_unit 

pub fn whole_unit(d: Duration) -> Unit
Selects the largest integral unit represented by a duration.

The stored value is rounded down to a whole unit. A zero duration is represented as Unit::Nanos(0).