pub struct AppService {
pub id: String,
pub url: Option<String>,
pub as_token: String,
pub hs_token: String,
pub sender_localpart: Option<String>,
pub users: Vec<AppServiceNamespace>,
pub aliases: Vec<AppServiceNamespace>,
pub rooms: Vec<AppServiceNamespace>,
pub rate_limited: bool,
pub protocols: Vec<String>,
pub receive_ephemeral: bool,
pub device_management: bool,
}Fields
id: Stringurl: Option<String>The URL for the application service.
Optionally set to null if no traffic is required.
as_token: StringA unique token for application services to use to authenticate requests to Homeservers.
default: display: sensitive
hs_token: StringA unique token for Homeservers to use to authenticate requests to application services.
default: display: sensitive
sender_localpart: Option<String>The localpart of the user associated with the application service.
users: Vec<AppServiceNamespace>Events which are sent from certain users.
aliases: Vec<AppServiceNamespace>Events which are sent in rooms with certain room aliases.
rooms: Vec<AppServiceNamespace>Events which are sent in rooms with certain room IDs.
rate_limited: boolWhether requests from masqueraded users are rate-limited.
The sender is excluded.
protocols: Vec<String>The external protocols which the application service provides (e.g. IRC).
default: []
receive_ephemeral: boolWhether the application service wants to receive ephemeral data.
default: false
device_management: boolWhether the application service wants to do device management, as part of MSC4190.
default: false