pub struct WellKnownConfig {
pub client: Option<Url>,
pub server: Option<OwnedServerName>,
pub support_page: Option<Url>,
pub support_role: Option<ContactRole>,
pub support_email: Option<String>,
pub support_mxid: Option<OwnedUserId>,
pub livekit_url: Option<String>,
pub rtc_transports: Vec<Value>,
}Fields
client: Option<Url>The server URL that the client well-known file will serve. This should not contain a port, and should just be a valid HTTPS URL.
example: “https://matrix.example.com”
server: Option<OwnedServerName>The server base domain of the URL with a specific port that the server well-known file will serve. This should contain a port at the end, and should not be a URL.
reloadable: yes example: “matrix.example.com:443”
support_page: Option<Url>The URL of the support web page. This and the below generate the content
of /.well-known/matrix/support.
reloadable: yes example: “https://example.com/support”
support_role: Option<ContactRole>The name of the support role.
reloadable: yes example: “m.role.admin”
support_email: Option<String>The email address for the above support role.
reloadable: yes example: “admin@example.com”
support_mxid: Option<OwnedUserId>The Matrix User ID for the above support role.
example “@admin:example.com” reloadable: yes
livekit_url: Option<String>LiveKit JWT endpoint. Required for Element Call / MatrixRTC (MSC4143).
Note: You must also set client above to your homeserver URL.
reloadable: yes default: “”
rtc_transports: Vec<Value>Custom MatrixRTC transports.
If you’re looking to setup Element Call / MatrixRTC with Livekit,
you should not use this option and instead set livekit_url.
This is only required if you want to configure a non-livekit MatrixRTC
transport. There are no known client implementations that support any
other transport types.
This option was previously the only way to configure a Livekit
transport. It has been superseded by livekit_url.
Example:
[global.well_known]
client = "https://matrix.yourdomain.com"
[[global.well_known.rtc_transports]]
type = "livekit"
livekit_service_url = "https://livekit.yourdomain.com"reloadable: yes default: []