pub enum Error {
Show 65 variants
PanicAny(Mutex<Box<dyn Any + Send>>),
Panic(&'static str, Mutex<Box<dyn Any + Send + 'static>>),
Fmt(Error),
FromUtf8(FromUtf8Error),
Io(Error),
ParseFloat(ParseFloatError),
ParseInt(ParseIntError),
Std(Box<dyn Error + Send + Sync + 'static>),
SystemTime(SystemTimeError),
ThreadAccessError(AccessError),
TryFromInt(TryFromIntError),
TryFromSlice(TryFromSliceError),
Utf8(Utf8Error),
CapacityError(CapacityError),
CargoToml(Error),
Clap(Error),
Errno(Errno),
Extension(ExtensionRejection),
Figment(Error),
HtmlFormDe(Error),
HtmlFormSer(Error),
Http(Error),
HttpHeader(InvalidHeaderValue),
JoinError(JoinError),
Json(Error),
JsParseInt(JsParseIntError),
JsTryFromInt(JsTryFromIntError),
ObjectStore(Error),
Path(PathRejection),
Poison(Cow<'static, str>),
Regex(Error),
Reqwest(Error),
SerdeDe(Cow<'static, str>),
SerdeSer(Cow<'static, str>),
TomlDe(Error),
TomlSer(Error),
TracingFilter(ParseError),
TracingReload(Error),
TypedHeader(TypedHeaderRejection),
UrlParse(ParseError),
Yaml(Error),
Arithmetic(Cow<'static, str>),
BadRequest(ErrorKind, &'static str),
BadServerResponse(Cow<'static, str>),
CanonicalJson(CanonicalJsonError),
Config(&'static str, Cow<'static, str>),
Conflict(Cow<'static, str>),
ContentDisposition(ContentDispositionParseError),
Database(Cow<'static, str>),
FeatureDisabled(Cow<'static, str>),
Federation(OwnedServerName, Error),
HttpJson(StatusCode, Json<Value>),
InconsistentRoomState(&'static str, OwnedRoomId),
IntoHttp(IntoHttpError),
Ldap(Cow<'static, str>),
Mxc(MxcUriError),
Mxid(IdParseError),
PowerLevels(PowerLevelsError),
Redaction(OwnedServerName, CanonicalJsonFieldError),
Request(ErrorKind, Cow<'static, str>, StatusCode),
Ruma(Error),
Signatures(VerificationError),
SignaturesJson(JsonError),
Uiaa(UiaaInfo),
Err(Cow<'static, str>),
}Variants
PanicAny(Mutex<Box<dyn Any + Send>>)
Panic(&'static str, Mutex<Box<dyn Any + Send + 'static>>)
Fmt(Error)
FromUtf8(FromUtf8Error)
Io(Error)
ParseFloat(ParseFloatError)
ParseInt(ParseIntError)
Std(Box<dyn Error + Send + Sync + 'static>)
SystemTime(SystemTimeError)
ThreadAccessError(AccessError)
TryFromInt(TryFromIntError)
TryFromSlice(TryFromSliceError)
Utf8(Utf8Error)
CapacityError(CapacityError)
CargoToml(Error)
Clap(Error)
Errno(Errno)
Extension(ExtensionRejection)
Figment(Error)
HtmlFormDe(Error)
HtmlFormSer(Error)
Http(Error)
HttpHeader(InvalidHeaderValue)
JoinError(JoinError)
Json(Error)
JsParseInt(JsParseIntError)
JsTryFromInt(JsTryFromIntError)
ObjectStore(Error)
Path(PathRejection)
Poison(Cow<'static, str>)
Regex(Error)
Reqwest(Error)
SerdeDe(Cow<'static, str>)
SerdeSer(Cow<'static, str>)
TomlDe(Error)
TomlSer(Error)
TracingFilter(ParseError)
TracingReload(Error)
TypedHeader(TypedHeaderRejection)
UrlParse(ParseError)
Yaml(Error)
Arithmetic(Cow<'static, str>)
BadRequest(ErrorKind, &'static str)
BadServerResponse(Cow<'static, str>)
CanonicalJson(CanonicalJsonError)
Config(&'static str, Cow<'static, str>)
Conflict(Cow<'static, str>)
ContentDisposition(ContentDispositionParseError)
Database(Cow<'static, str>)
FeatureDisabled(Cow<'static, str>)
Federation(OwnedServerName, Error)
HttpJson(StatusCode, Json<Value>)
InconsistentRoomState(&'static str, OwnedRoomId)
IntoHttp(IntoHttpError)
Ldap(Cow<'static, str>)
Mxc(MxcUriError)
Mxid(IdParseError)
PowerLevels(PowerLevelsError)
Redaction(OwnedServerName, CanonicalJsonFieldError)
Request(ErrorKind, Cow<'static, str>, StatusCode)
Ruma(Error)
Signatures(VerificationError)
SignaturesJson(JsonError)
Uiaa(UiaaInfo)
Err(Cow<'static, str>)
Implementations
Sourceimpl Error
impl Error
Sourceimpl Error
impl Error
pub fn from_errno() -> Self
pub fn bad_database(message: &'static str) -> Self
Sourcepub fn sanitized_message(&self) -> String
pub fn sanitized_message(&self) -> String
Sanitizes public-facing errors that can leak sensitive information.
Sourcepub fn status_code(&self) -> StatusCode
pub fn status_code(&self) -> StatusCode
Returns the HTTP error code or closest approximation based on error variant.
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Returns true for “not found” errors. This means anything that qualifies as a “not found” from any variant’s contained error type. This call is often used as a special case to eliminate a contained Option with a Result where Ok(None) is instead Err(e) if e.is_not_found().