pub fn infallible(_e: &Infallible)Expand description
Marks an impossible Infallible error path.
The argument cannot be constructed in safe code, so reaching this function indicates a violated invariant.
Panics
Always panics because an Infallible error cannot legitimately exist.