pub fn map_log<E>(error: E) -> ErrorExpand description
Converts and logs an error while returning the converted value.
Display-formatted logging occurs after conversion to Error. The same
converted error is returned for propagation by combinator chains.