macro_rules! at {
($idx:tt) => { ... };
}Expand description
Creates a closure that selects an indexed tuple field by value.
The generated closure consumes its tuple argument and returns the selected field.
macro_rules! at {
($idx:tt) => { ... };
}Creates a closure that selects an indexed tuple field by value.
The generated closure consumes its tuple argument and returns the selected field.