macro_rules! debug {
( $($x:tt)+ ) => { ... };
}Expand description
Emits a debug-level tracing event.
The macro forwards all fields and message tokens to tracing::debug!.
Project code can use it without importing the tracing crate directly.
macro_rules! debug {
( $($x:tt)+ ) => { ... };
}Emits a debug-level tracing event.
The macro forwards all fields and message tokens to tracing::debug!.
Project code can use it without importing the tracing crate directly.