macro_rules! deref_at {
($idx:tt) => { ... };
}Expand description
Creates a closure that dereferences an indexed tuple field.
The tuple argument is received by value, and the selected field is returned through unary dereference.
macro_rules! deref_at {
($idx:tt) => { ... };
}Creates a closure that dereferences an indexed tuple field.
The tuple argument is received by value, and the selected field is returned through unary dereference.