err_log

Macro err_log 

macro_rules! err_log {
    ($out:ident, $level:ident, $($fields:tt)+) => { ... };
}
A trinity of integration between tracing, logging, and Error. This is a customization of tracing::event! with the primary purpose of sharing the error string, fieldset parsing and formatting. An added benefit is that we can share the same callsite metadata for the source of our Error and the associated logging and tracing event dispatches.