macro_rules! error {
( $($x:tt)+ ) => { ... };
}Expand description
Emits an error-level tracing event.
The macro forwards all fields and message tokens to tracing::error!.
Project code can use it without importing the tracing crate directly.
macro_rules! error {
( $($x:tt)+ ) => { ... };
}Emits an error-level tracing event.
The macro forwards all fields and message tokens to tracing::error!.
Project code can use it without importing the tracing crate directly.