expected

Macro expected 

macro_rules! expected {
    ($msg:literal, $($input:tt)+) => { ... };
    ($($input:tt)+) => { ... };
}
Checked arithmetic expression which panics on failure. This is for expressions which do not meet the threshold for validated! but the caller has no realistic expectation for error and no interest in cluttering the callsite with result handling from checked!.