macro_rules! format_maybe {
($s:literal $(,)?) => { ... };
($s:literal, $($args:tt)+) => { ... };
}Expand description
Formats a literal only when placeholders appear to be present.
With one argument, a literal containing both { and } is formatted; any
other literal is converted directly through Into. With additional
arguments, the first literal is always treated as a format string.