macro_rules! info {
( $($x:tt)+ ) => { ... };
}Expand description
Emits an informational tracing event.
The macro forwards all fields and message tokens to tracing::info!.
Project code can use it without importing the tracing crate directly.
macro_rules! info {
( $($x:tt)+ ) => { ... };
}Emits an informational tracing event.
The macro forwards all fields and message tokens to tracing::info!.
Project code can use it without importing the tracing crate directly.