macro_rules! is_matching {
($val:ident) => { ... };
($($val:tt)+) => { ... };
}Expand description
Creates a closure that tests its input with a matches! pattern.
The supplied tokens can contain any pattern form accepted by matches!. The
closure returns false when the input does not match.