macro_rules! is_nonzero {
() => { ... };
}Expand description
Creates a closure that reports whether its input differs from zero.
The generated closure compares each input with the integer literal 0.
macro_rules! is_nonzero {
() => { ... };
}Creates a closure that reports whether its input differs from zero.
The generated closure compares each input with the integer literal 0.