macro_rules! maybe_unhandled {
($msg:literal) => { ... };
}Expand description
Panics with the supplied message for a branch that is not implemented.
This macro always retains a runtime failure path and can therefore mark code that may remain reachable.