macro_rules! ref_at {
($idx:tt) => { ... };
}Expand description
Creates a closure that borrows an indexed tuple field.
The generated ref pattern borrows the tuple argument before returning a
reference to the selected field.
macro_rules! ref_at {
($idx:tt) => { ... };
}Creates a closure that borrows an indexed tuple field.
The generated ref pattern borrows the tuple argument before returning a
reference to the selected field.