macro_rules! trace {
( $($x:tt)+ ) => { ... };
}Expand description
Emits a trace-level tracing event.
The macro forwards all fields and message tokens to tracing::trace!.
Project code can use it without importing the tracing crate directly.
macro_rules! trace {
( $($x:tt)+ ) => { ... };
}Emits a trace-level tracing event.
The macro forwards all fields and message tokens to tracing::trace!.
Project code can use it without importing the tracing crate directly.