macro_rules! validated {
($($input:tt)+) => { ... };
}Expand description
Checked arithmetic expression in debug-mode. Use for performance when the expression is obviously safe. The check is elided in release-mode.
macro_rules! validated {
($($input:tt)+) => { ... };
}Checked arithmetic expression in debug-mode. Use for performance when the expression is obviously safe. The check is elided in release-mode.