macro_rules! warn {
( $($x:tt)+ ) => { ... };
}Expand description
Emits a warning-level tracing event.
The macro forwards all fields and message tokens to tracing::warn!.
Project code can use it without importing the tracing crate directly.
macro_rules! warn {
( $($x:tt)+ ) => { ... };
}Emits a warning-level tracing event.
The macro forwards all fields and message tokens to tracing::warn!.
Project code can use it without importing the tracing crate directly.