pub(super) fn copy<E: Event>(event: &E) -> (Option<OwnedEventId>, Box<RawValue>)Expand description
Copies the redacts property of the event to the content dict and
vice-versa.
This follows the specification’s recommendation:
For backwards-compatibility with older clients, servers should add a redacts property to the top level of m.room.redaction events in when serving such events over the Client-Server API.
For improved compatibility with newer clients, servers should add a redacts property to the content of m.room.redaction events in older room versions when serving such events over the Client-Server API.