pub struct PduBuilder {
pub event_type: TimelineEventType,
pub content: Box<RawValue>,
pub unsigned: Option<BTreeMap<String, Value>>,
pub state_key: Option<StateKey>,
pub redacts: Option<OwnedEventId>,
pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}Expand description
Build the start of a PDU in order to add it to the Database.
Fields
event_type: TimelineEventTypecontent: Box<RawValue>unsigned: Option<BTreeMap<String, Value>>state_key: Option<StateKey>redacts: Option<OwnedEventId>timestamp: Option<MilliSecondsSinceUnixEpoch>For timestamped messaging, should only be used for appservices. Will be set to current time if None
Implementations