pub fn from_create_content(content: &RoomCreateEventContent) -> &RoomVersionIdExpand description
Borrows the room version from parsed room creation content.
Ruma applies the protocol default while deserializing content that omits the field. This accessor performs no additional validation.