pub struct Server {
pub name: OwnedServerName,
pub config: Manager,
pub started: SystemTime,
pub stopping: AtomicBool,
pub reloading: AtomicBool,
pub restarting: AtomicBool,
pub runtime: Option<Handle>,
pub signal: Sender<&'static str>,
pub log: Logging,
pub metrics: Arc<Metrics>,
}Expand description
Server runtime state; public portion
Fields
name: OwnedServerNameConfigured name of server. This is the same as the one in the config but developers can (and should) reference this string instead.
config: ManagerServer-wide configuration instance
started: SystemTimeTimestamp server was started; used for uptime.
stopping: AtomicBoolReload/shutdown pending indicator; server is shutting down. This is an observable used on shutdown and should not be modified.
reloading: AtomicBoolReload/shutdown desired indicator; when false, shutdown is desired. This is an observable used on shutdown and modifying is not recommended.
restarting: AtomicBoolRestart desired; when true, restart it desired after shutdown.
runtime: Option<Handle>Handle to the runtime
signal: Sender<&'static str>Reload/shutdown signal
log: LoggingLogging subsystem state
metrics: Arc<Metrics>Metrics subsystem state
Implementations
Sourceimpl Server
impl Server
pub fn new( config: Config, runtime: Option<&Handle>, log: Logging, metrics: Arc<Metrics>, ) -> Self
pub fn reload(&self) -> Result
pub fn restart(&self) -> Result
pub fn shutdown(&self) -> Result
pub fn signal(&self, sig: &'static str) -> Result
pub async fn until_shutdown(self: &Arc<Self>)
pub fn runtime(&self) -> &Handle
pub fn check_running(&self) -> Result
pub fn is_running(&self) -> bool
pub fn is_stopping(&self) -> bool
pub fn is_reloading(&self) -> bool
pub fn is_restarting(&self) -> bool
pub fn is_ours(&self, name: &str) -> bool