pub trait OptionStream<T> {
// Required method
fn stream(self) -> impl Stream<Item = T> + Send;
}Expand description
Converts an optional future of initial and trailing items into a stream.
A present future yields its iterable items before chaining its trailing stream. An absent future becomes an empty stream.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".