pub fn automatic_width() -> usizeExpand description
Used by stream operations where the concurrency factor hasn’t been manually supplied by the caller (most uses). Instead we provide a default value which is adjusted at startup for the specific system and also dynamically.