Unquote

Trait Unquote 

pub trait Unquote<'a> {
    // Required methods
    fn is_quoted(&self) -> bool;
    fn unquote(&self) -> Option<&'a str>;
    fn unquote_infallible(&self) -> &'a str;
}
Slice a string between quotes

Required Methods

fn is_quoted(&self) -> bool

Whether the input is quoted. If this is false the fallible methods of this interface will fail.

fn unquote(&self) -> Option<&'a str>

Unquotes a string. If the input is not quoted it is simply returned as-is. If the input is partially quoted on either end that quote is not removed.

fn unquote_infallible(&self) -> &'a str

Unquotes a string. The input must be quoted on each side for Some to be returned

Implementations on Foreign Types

Source

impl<'a> Unquote<'a> for &'a str

Source

fn unquote_infallible(&self) -> &'a str

Source

fn unquote(&self) -> Option<&'a str>

Source

fn is_quoted(&self) -> bool

Implementors