maximize_fd_limit

Function maximize_fd_limit 

pub fn maximize_fd_limit() -> Result
This is needed for opening lots of file descriptors, which tends to happen more often when using RocksDB and making lots of federation connections at startup. The soft limit is usually 1024, and the hard limit is usually 512000; I’ve personally seen it hit >2000.