pub fn maximize_thread_limit() -> ResultExpand description
Raises the soft thread limit to the current hard limit.
Some distributions default to about 1,024 threads, which can constrain hosts with 32 or more cores. Thread limits are otherwise reached less often than file descriptor limits.