maximize_thread_limit

Function maximize_thread_limit 

pub fn maximize_thread_limit() -> Result
Some distributions ship with very low defaults for thread counts; similar to low default file descriptor limits. But unlike fd’s, thread limit is rarely reached, though on large systems (32+ cores) shipping with defaults of ~1024 as have been observed are problematic.