Struct Usage
#[repr(transparent)]pub struct Usage(rusage);Expand description
Output of getrusage with information about resource usage. Some of the fields
may be unused in some platforms, and will be always zeroed out. See their manuals
for details.
Tuple Fields
0: rusageImplementations
impl Usage
impl Usage
pub fn user_time(&self) -> TimeVal
pub fn user_time(&self) -> TimeVal
Total amount of time spent executing in user mode.
pub fn system_time(&self) -> TimeVal
pub fn system_time(&self) -> TimeVal
Total amount of time spent executing in kernel mode.
Integral value expressed in kilobytes times ticks of execution indicating the amount of text memory shared with other processes.
Integral value expressed in kilobytes times ticks of execution indicating the amount of unshared memory used by data.
Integral value expressed in kilobytes times ticks of execution indicating the amount of unshared memory used for stack space.
pub fn minor_page_faults(&self) -> i64
pub fn minor_page_faults(&self) -> i64
Number of page faults that were served without resorting to I/O, with pages that have been allocated previously by the kernel.
pub fn major_page_faults(&self) -> i64
pub fn major_page_faults(&self) -> i64
Number of page faults that were served through I/O (i.e. swap).
pub fn full_swaps(&self) -> i64
pub fn full_swaps(&self) -> i64
Number of times all of the memory was fully swapped out.
pub fn block_reads(&self) -> i64
pub fn block_reads(&self) -> i64
Number of times a read was done from a block device.
pub fn block_writes(&self) -> i64
pub fn block_writes(&self) -> i64
Number of times a write was done to a block device.
pub fn ipc_receives(&self) -> i64
pub fn ipc_receives(&self) -> i64
Number of IPC messages received.
pub fn voluntary_context_switches(&self) -> i64
pub fn voluntary_context_switches(&self) -> i64
Number of times a context switch was voluntarily invoked.
pub fn involuntary_context_switches(&self) -> i64
pub fn involuntary_context_switches(&self) -> i64
Number of times a context switch was imposed by the kernel (usually due to time slice expiring or preemption by a higher priority process).