pub fn timepoint_from_epoch(duration: Duration) -> Result<SystemTime>Expand description
Adds a duration to the Unix epoch using checked arithmetic.
The resulting system time is returned when representable. An arithmetic
error is returned when the duration exceeds the platform’s SystemTime
range.