pub fn timepoint_has_passed(timepoint: SystemTime) -> boolExpand description
Checks whether a system time is at or before the current wall-clock time.
Equality is considered passed. A time later than the sampled current time
returns false.
pub fn timepoint_has_passed(timepoint: SystemTime) -> boolChecks whether a system time is at or before the current wall-clock time.
Equality is considered passed. A time later than the sampled current time
returns false.