pub fn whole_and_frac(d: Duration) -> (Unit, f64)
Return a pair of (whole part, frac part) from a duration where. The whole part is the largest Unit containing a non-zero value, the frac part is a rational remainder left over.